pub enum Message<'a> {
Literal {
reader: LiteralDataReader<MessageReader<'a>>,
is_nested: bool,
},
Compressed {
reader: CompressedDataReader<MessageReader<'a>>,
is_nested: bool,
},
Signed {
reader: SignatureManyReader<'a>,
is_nested: bool,
},
Encrypted {
esk: Vec<Esk>,
edata: Edata<'a>,
is_nested: bool,
},
}Expand description
Represents one of:
- Encrypted Message,
- Signed Message (either one-pass signed or prefixed-signed),
- Compressed Message,
- Literal Message.
OpenPGP message may consist of multiple layers wrapped around each other (such as for example: an encrypted message, containing a compressed message, containing a one-pass signed message, containing a literal message).
Variants
Literal
Literal Message: Literal Data Packet.
Compressed
Compressed Message: Compressed Data Packet.
Signed
Signed message, either
- Signed: Signature Packet, OpenPGP Message, or
- One Pass Signed: One-Pass Signature Packet, OpenPGP Message, Corresponding Signature Packet.
Encrypted
Encrypted Message: Encrypted Data | ESK Sequence, Encrypted Data.
Implementations
Sourceimpl<'a> Message<'a>
impl<'a> Message<'a>
Sourcepub fn from_bytes<R: BufRead + Debug + 'a + Send>(source: R) -> Result<Self>
pub fn from_bytes<R: BufRead + Debug + 'a + Send>(source: R) -> Result<Self>
Parses a message from the given bytes.
Sourcepub fn from_string(data: &'a str) -> Result<(Self, Headers)>
pub fn from_string(data: &'a str) -> Result<(Self, Headers)>
From armored string
Sourcepub fn from_armor<R: BufRead + Debug + 'a + Send>(
input: R,
) -> Result<(Self, Headers)>
pub fn from_armor<R: BufRead + Debug + 'a + Send>( input: R, ) -> Result<(Self, Headers)>
Armored ascii data.
Sourcepub fn from_armor_with_options<R: BufRead + Debug + 'a + Send>(
input: R,
opt: DearmorOptions,
) -> Result<(Self, Headers)>
pub fn from_armor_with_options<R: BufRead + Debug + 'a + Send>( input: R, opt: DearmorOptions, ) -> Result<(Self, Headers)>
Armored ascii data, with explicit options for dearmoring.
Sourceimpl<'a> Message<'a>
impl<'a> Message<'a>
Sourcepub fn decompress(self) -> Result<Self>
pub fn decompress(self) -> Result<Self>
Decompresses the data if compressed.
Sourcepub fn verify_nested(
&self,
keys: &[&dyn VerifyingKey],
) -> Result<Vec<VerificationResult>>
pub fn verify_nested( &self, keys: &[&dyn VerifyingKey], ) -> Result<Vec<VerificationResult>>
Recursively find all signatures found in this message and attempt to verify them against the passed in keys.
Only signed and one pass signed messages can be verified. The message must have been read to the end before calling this.
The current recursion limit is 1024.
Sourcepub fn verify_read(&mut self, key: &dyn VerifyingKey) -> Result<&Signature>
pub fn verify_read(&mut self, key: &dyn VerifyingKey) -> Result<&Signature>
Reads the contents and discards it, then verifies the message.
Sourcepub fn verify(&self, key: &dyn VerifyingKey) -> Result<&Signature>
pub fn verify(&self, key: &dyn VerifyingKey) -> Result<&Signature>
Verify this message.
Only signed and one pass signed messages can be verified. The message must have been read to the end before calling this.
If the signature is valid, returns the matching signature.
pub fn verify_nested_explicit( &self, index: usize, key: &dyn VerifyingKey, ) -> Result<&Signature>
Sourcepub fn decrypt(
self,
key_pw: &Password,
key: &SignedSecretKey,
) -> Result<Message<'a>>
pub fn decrypt( self, key_pw: &Password, key: &SignedSecretKey, ) -> Result<Message<'a>>
Decrypt the message using the given key. Returns a message decryptor.
Sourcepub fn decrypt_with_keys(
self,
key_passwords: Vec<&Password>,
secret_keys: Vec<&SignedSecretKey>,
) -> Result<Message<'a>>
pub fn decrypt_with_keys( self, key_passwords: Vec<&Password>, secret_keys: Vec<&SignedSecretKey>, ) -> Result<Message<'a>>
Decrypt the message using the given keys. Returns a message decryptor.
Sourcepub fn decrypt_legacy(
self,
key_pw: &Password,
key: &SignedSecretKey,
) -> Result<Message<'a>>
pub fn decrypt_legacy( self, key_pw: &Password, key: &SignedSecretKey, ) -> Result<Message<'a>>
Decrypt the message using the given key. Returns a message decryptor.
HAZMAT: Decrypts (malleable) SED packets.
Sourcepub fn decrypt_with_password(self, msg_pw: &Password) -> Result<Message<'a>>
pub fn decrypt_with_password(self, msg_pw: &Password) -> Result<Message<'a>>
Decrypt the message using the given key. Returns a message decryptor.
pub fn decrypt_with_session_key( self, session_key: PlainSessionKey, ) -> Result<Message<'a>>
Sourcepub fn decrypt_the_ring(
self,
ring: TheRing<'_>,
abort_early: bool,
) -> Result<(Message<'a>, RingResult)>
pub fn decrypt_the_ring( self, ring: TheRing<'_>, abort_early: bool, ) -> Result<(Message<'a>, RingResult)>
The most powerful and flexible way to decrypt. Give it all you know, and maybe something will come of it.
If abort_early is true, the first available session key will be used, even if it might be wrong, or mismatch
with others.
If it is set to false, all provided keys, and passwords will be checked and compared.
In this case, if there are different session keys found, it will error out.
Sourcepub fn is_one_pass_signed(&self) -> bool
pub fn is_one_pass_signed(&self) -> bool
Check if this message is a signature, that was signed with a one pass signature.
pub fn is_encrypted(&self) -> bool
pub fn is_signed(&self) -> bool
Sourcepub fn is_compressed(&self) -> bool
pub fn is_compressed(&self) -> bool
Is this a compressed message?
Sourcepub fn is_literal(&self) -> bool
pub fn is_literal(&self) -> bool
Is this a literal message?
Sourcepub fn literal_data_header(&self) -> Option<&LiteralDataHeader>
pub fn literal_data_header(&self) -> Option<&LiteralDataHeader>
If this is a literal message, returns the literal data header
pub fn packet_header(&self) -> PacketHeader
Sourcepub fn as_data_vec(&mut self) -> Result<Vec<u8>>
pub fn as_data_vec(&mut self) -> Result<Vec<u8>>
Consumes the reader and reads into a vec.
Sourcepub fn as_data_string(&mut self) -> Result<String>
pub fn as_data_string(&mut self) -> Result<String>
Consumes the reader and reads into a string.
pub fn into_inner(self) -> PacketBodyReader<MessageReader<'a>> ⓘ
pub fn get_mut(&mut self) -> &mut PacketBodyReader<MessageReader<'a>> ⓘ