pub enum SubpacketConfig {
Default,
UserDefined {
hashed: Vec<Subpacket>,
unhashed: Vec<Subpacket>,
},
}Expand description
Subpacket configuration for a data signature (either in the context of a message, or as a detached signature).
The subpacket configuration may either be implicit (relying on rPGP to set default subpackets), or user-provided and explicit (consisting of lists of hashed and unhashed subpackets).
Variants
Default
Signature subpackets are automatically produced while signing.
This produces two hashed subpackets: IssuerFingerprint and SignatureCreationTime.
In addition, for v4 keys, an IssuerKeyId subpacket is added to the unhashed area
(showing the signer’s Key ID).
UserDefined
Caller-provided exact subpacket configuration. The lists of subpackets will be used in the signature verbatim, and without any additions.
CAUTION: For interoperability with other OpenPGP implementations, it’s important to set signature subpackets appropriately! Also see https://datatracker.ietf.org/doc/draft-gallagher-openpgp-signatures/