pub enum ImageHeader {
V1(ImageHeaderV1),
Unknown {
version: u8,
data: Bytes,
},
}Expand description
An image header is used in the image attribute subpacket.
This subpacket is used in UserAttribute packets.
See https://www.rfc-editor.org/rfc/rfc9580.html#name-image-attribute-subpacket
Note that the Image Attribute subpacket are not commonly used.
Variants
Implementations
Sourceimpl ImageHeader
impl ImageHeader
pub fn try_from_reader<B: BufRead>(i: B) -> Result<Self>