Message

Enum Message 

pub enum Message<'a> {
    Literal {
        reader: LiteralDataReader<MessageReader<'a>>,
        is_nested: bool,
    },
    Compressed {
        reader: CompressedDataReader<MessageReader<'a>>,
        is_nested: bool,
    },
    Signed {
        reader: SignatureManyReader<'a>,
        is_nested: bool,
    },
    Encrypted {
        esk: Vec<Esk>,
        edata: Edata<'a>,
        is_nested: bool,
    },
}
An OpenPGP message

Represents one of:

  • Encrypted Message,
  • Signed Message (either one-pass signed or prefixed-signed),
  • Compressed Message,
  • Literal Message.

OpenPGP message may consist of multiple layers wrapped around each other (such as for example: an encrypted message, containing a compressed message, containing a one-pass signed message, containing a literal message).

Variants



Literal

Literal Message: Literal Data Packet.

Fields

is_nested: bool

is this a nested message?



Compressed

Compressed Message: Compressed Data Packet.

Fields

is_nested: bool

is this a nested message?



Signed

Signed message, either

  • Signed: Signature Packet, OpenPGP Message, or
  • One Pass Signed: One-Pass Signature Packet, OpenPGP Message, Corresponding Signature Packet.

Fields

is_nested: bool

is this a nested message?



Encrypted

Encrypted Message: Encrypted Data | ESK Sequence, Encrypted Data.

Fields

esk: Vec<Esk>

ESK Sequence: ESK | ESK Sequence, ESK.

edata: Edata<'a>
is_nested: bool

is this a nested message?

Implementations

Source

impl<'a> Message<'a>

pub fn from_bytes<R: BufRead + Debug + 'a + Send>(source: R) -> Result<Self>

Parses a message from the given bytes.

pub fn from_armor_file<P: AsRef<Path>>(path: P) -> Result<(Self, Headers)>

From armored file

pub fn from_string(data: &'a str) -> Result<(Self, Headers)>

From armored string

pub fn from_file<P: AsRef<Path>>(path: P) -> Result<Self>

From binary file

pub fn from_armor<R: BufRead + Debug + 'a + Send>( input: R, ) -> Result<(Self, Headers)>

Armored ascii data.

pub fn from_armor_with_options<R: BufRead + Debug + 'a + Send>( input: R, opt: DearmorOptions, ) -> Result<(Self, Headers)>

Armored ascii data, with explicit options for dearmoring.

pub fn from_reader<R: BufRead + Debug + 'a + Send>( source: R, ) -> Result<(Self, Option<Headers>)>

Parse from a reader which might contain ASCII armored data or binary data.

Source

impl<'a> Message<'a>

pub fn decompress(self) -> Result<Self>

Decompresses the data if compressed.

pub fn verify_nested( &self, keys: &[&dyn VerifyingKey], ) -> Result<Vec<VerificationResult>>

Recursively find all signatures found in this message and attempt to verify them against the passed in keys.

Only signed and one pass signed messages can be verified. The message must have been read to the end before calling this.

The current recursion limit is 1024.

pub fn verify_read(&mut self, key: &dyn VerifyingKey) -> Result<&Signature>

Reads the contents and discards it, then verifies the message.

pub fn verify(&self, key: &dyn VerifyingKey) -> Result<&Signature>

Verify this message.

Only signed and one pass signed messages can be verified. The message must have been read to the end before calling this.

If the signature is valid, returns the matching signature.

pub fn verify_nested_explicit( &self, index: usize, key: &dyn VerifyingKey, ) -> Result<&Signature>

pub fn decrypt( self, key_pw: &Password, key: &SignedSecretKey, ) -> Result<Message<'a>>

Decrypt the message using the given key. Returns a message decryptor.

pub fn decrypt_with_keys( self, key_passwords: Vec<&Password>, secret_keys: Vec<&SignedSecretKey>, ) -> Result<Message<'a>>

Decrypt the message using the given keys. Returns a message decryptor.

pub fn decrypt_legacy( self, key_pw: &Password, key: &SignedSecretKey, ) -> Result<Message<'a>>

Decrypt the message using the given key. Returns a message decryptor.

HAZMAT: Decrypts (malleable) SED packets.

pub fn decrypt_with_password(self, msg_pw: &Password) -> Result<Message<'a>>

Decrypt the message using the given key. Returns a message decryptor.

pub fn decrypt_with_session_key( self, session_key: PlainSessionKey, ) -> Result<Message<'a>>

pub fn decrypt_the_ring( self, ring: TheRing<'_>, abort_early: bool, ) -> Result<(Message<'a>, RingResult)>

The most powerful and flexible way to decrypt. Give it all you know, and maybe something will come of it.

If abort_early is true, the first available session key will be used, even if it might be wrong, or mismatch with others. If it is set to false, all provided keys, and passwords will be checked and compared. In this case, if there are different session keys found, it will error out.

pub fn is_one_pass_signed(&self) -> bool

Check if this message is a signature, that was signed with a one pass signature.

pub fn is_encrypted(&self) -> bool

pub fn is_signed(&self) -> bool

pub fn is_compressed(&self) -> bool

Is this a compressed message?

pub fn is_literal(&self) -> bool

Is this a literal message?

pub fn literal_data_header(&self) -> Option<&LiteralDataHeader>

If this is a literal message, returns the literal data header

pub fn packet_header(&self) -> PacketHeader

pub fn as_data_vec(&mut self) -> Result<Vec<u8>>

Consumes the reader and reads into a vec.

pub fn as_data_string(&mut self) -> Result<String>

Consumes the reader and reads into a string.

pub fn into_inner(self) -> PacketBodyReader<MessageReader<'a>>

pub fn get_mut(&mut self) -> &mut PacketBodyReader<MessageReader<'a>>